# A GH81-type β-glucan-binding protein enhances colonization by mutualistic fungi in barley
## Original publication
Wanke, A., van Boerdonk, S., Mahdi, L. K., Wawra, S., Neidert, M., Chandrasekar, B., Saake, P., Saur, I. M. L., Derbyshire, P., Holton, N., Menke, F. L. H., Brands, M., Pauly, M., Acosta, I. F., Zipfel, C., & Zuccaro, A. (2023). A GH81-type β-glucan-binding protein enhances colonization by mutualistic fungi in barley. Current biology : CB, 33(23), 5071–5084.e7. https://doi.org/10.1016/j.cub.2023.10.048

## License
Copyright © 2023 The Authors. Published by Elsevier Inc. All rights reserved.

## Data availability

Lead Contact

Further information and requests for resources, reagents, datasets, and protocols should be directed to and will be fulfilled by the lead contact, Alga Zuccaro (azuccaro@uni-koeln.de).

Materials Availability

Plasmids and barley lines generated in this study are available upon request and will be provided by the lead contact, Alga Zuccaro (azuccaro@uni-koeln.de).

Data and Code Availability

Proteomic data has been deposited at the ProteomeXchange Consortium via PRIDE partner repository (Perez-Riverol et al., 2019) and are publicly available as of the date of publication. Accession numbers are listed in the key resources table.

This paper does not report original code.

Any additional information required to reanalyze the data reported in this paper is available from the lead contact upon request.

## ARC structure

``` mermaid
%%{
  init: {
    'theme': 'base',
    'themeVariables': {
      'background': '#fff',
      'lineColor': '#2d3e50',
      'primaryTextColor': '#2d3e50'
    }
  }
}%%

flowchart

subgraph Legend
l1(Sample)
l2>Process]
l3(Material)
l4(Data)
end

subgraph studies\NicotianaBenthamiana
direction TB
s1(wild type seeds)---p1>PlantMaterialAndGrowthConditions.md]-->s2(N. benthamiana plants)
end

subgraph studies\HordeumVulgare
direction TB
s3(barley seeds)---p2>PlantMaterialAndGrowthConditions.md]-->s4(barley plants)
end

subgraph studies\CarbohydrateSubstratesForImmunityAndEnzymaticDigestionAssays
direction TB
p3>CarbohydrateSubstratesForImmunityAndEnzymaticDigestionAssays.md]-->s5(carbohydrate substrates)
end

subgraph assays\HeterologousProteinProductionAndPurification
direction TB
a1(codon-optimized GBP1 sequence)---p4>PlasmidConstruction.md]-->a2(pXCScpmv-GBP1-HAStrep)
a3(catalitically inactive GBP1 sequence)---p4-->a4(pXCScpmv-GBP1_E500A-HAStrep)
a2----p6>"`isolation
        sequencing
        _Agrobacterium tumefaciens_ transformation`"]
a4---p5>"`gel electrophoresis
        purification
        _E.coli_ transformation`"]---p6
p6-->a5(Agrobacterium_GBP1)
p6-->a6(Agrobacterium_GBP1_E500A)
a5 & a6---p7>infiltration]
s2----p7
p7---p8>HeterologousProteinProductionAndPurification.md]-->a7(purified proteins)
end

subgraph assays\EnzymaticCarbohydrateDigestionAndTLC
direction TB
a7 & s5---p9>EnzymaticCarbohydrateDigestion.md]-->a8(digestion products)
a8---p10>TLC.md]-->d1("`gr3b_lrg.jpg
                    gr4a_lrg.jpg
                    gr4b_lrg.jpg
                    gr4c_lrg.jpg
                    FigS4A.jpg
                    FigS4B.jpg
                    FigS5A.png`")
end

subgraph assays\MALDI-TOFAnalysis
direction TB
a8---p11>MALDI-TOFAnalysis.md]-->d2("`gr3c_large.jpg
FigS4C.jpg`")
end

subgraph assays\CRISPRCas9-basedMutagenesis
direction TB
s4---p12>CRISPRCas9-basedMutagenesis.md]-->a9(barley mutants)-->d15(gr1b_lrg.jpg)
end

subgraph assays\OxidativeBurstAssay
direction TB
s2 & s4 & a9---p13>PreparationOfThePlantMaterial.md]-->a10(plant material)
a10---p14>ROSBurstAssay.md]-->d3("`gr5_lrg.jpg
                                FigS1A.jpg
                                FigS1B.jpg
                                FigS5B.jpg
                                FigS5C.jpg`")
end

subgraph assays\FungalMaterialGrowthConditionsAndBarleyColonizationAssays
direction TB
s4 & a9---p15>RhizophagusIrregularis.md]-->a11(R. irregularis colonized plants)-->d11(FigS3B.jpg)
s4 & a9---p16>BlumeriaHordei.md]-->a12(B. hordei colonized plants)-->d13(FigS3D.jpg)
s4 & a9---p17>SerendipitaIndicaSerendipitaVermiferaAndBipolarisSorokiniana.md]-->a13(S. indica colonized plants) & a14(S. vermifera colonized plants) & a15(B. sorokiniana colonized plants)
a15-->d12(FigS3C.jpg)
d14(gr6b_lrg.jpg)
end

subgraph assays\qRT-PCR
direction TB
a12 & a13 & a14 & a15---p18>qRT-PCR.md]-->d4("`gr1c_lrg.jpg
gr2_lrg.jpg
gr6d_lrg.jpg`")
end

subgraph assays\StainingForConfocalMicroscopy
direction TB
a13---p19>HordeumVulgare.md]-->d5("`gr6a_lrg.jpg
                                FigS6A.jpg
                                FigS6B.jpg
                                FigS6C.jpg`")
a11---p20>RootStainingOfRIrregularis.md]-->d6(FigS3A.jpg)
end

subgraph assays\ProteinPull-down
direction TB
a16(laminarin)---p21>BiotinylationOfLaminarin.md]-->a17(biotinylated laminarin)
s4 & a17---p22>ProteinPull-downWithBiotinylatedLaminarin.md]-->a18(pull-down proteins)
a18---p23>SDS-PAGE separation]-->d7(FigS1C.jpg)
end

subgraph assays\MS-MSAnalysisOfThePull-downProteins
direction TB
a18---p24>MS-MSAnalysisOfThePull-downProteins.md]-->d8("`gr1a_lrg.jpg
         mmc2.xlsx`")
end

subgraph assays\MultipleSequenceAlignment
d9(gr4a_lrg.jpg)
end

subgraph assays\QuantificationAndStatisticalAnalysis
direction TB
pr25>QuantificationAndStatisticalAnalysis.md]-->d10("`gr6c_lrg.jpg
        mmc3.xlsx`")
end

%% Defining node styles
  classDef S fill:#b4ce82, stroke:#333;
  classDef M fill:#ffc000;
  classDef D fill:#c21f3a,color:white;
  classDef P stroke-width:0px; 

%% Assigning styles to nodes
    class l1,a7,a8,a18 S;
    class l3,s1,s2,s3,s4,s5,a1,a2,a3,a4,a5,a6,a9,a10,a11,a12,a13,a14,a15,a16,a17 M;
    class d1,d2,d3,d4,d5,d6,d7,d8,d9,d10,d11,d12,d13,d14,d15,l4 D;
    class l2,p1,p2,p3,p4,p5,p6,p7,p8,p9,p10,p11,p12,p13,p14,p15,p16,p17,p18,p19,p20,p21,p22,p23,p24,p25 P;

